EntityLabel

Enum EntityLabel 

pub enum EntityLabel<K, T, L> {
    KeyLabel(Key<K>, L),
    Data(Box<T>),
    None,
}
Enum for situations when you want to define not just a Key but also a Label

This may be useful for faster access to avoid an extra LEFT JOIN or because you may have missing data, thus no Key, and having the Label makes the entity still valid

Variants



KeyLabel(Key<K>, L)

Key and Label for this entity



Data(Box<T>)

Created/Fetched data for the entity



None

For when you have no data to fill or null from database

Implementations

Source

impl<K, T, L> EntityLabel<K, T, L>

pub fn data(&self) -> Result<&T, Error>

Returns the data if it exists and was fetched/created

pub fn data_mut(&mut self) -> Result<&mut T, Error>

Returns the mutable data if it exists and was fetched/created

pub fn is_keylabel(&self) -> bool

Is this a KeyLabel variant?

pub fn is_data(&self) -> bool

Is this a Data variant?

pub fn is_none(&self) -> bool

Is this a None variant?